read_pcd

Function read_pcd 

pub fn read_pcd(path: &Path) -> Result<PointCloud, IoError>
Reads a cloud from PCD.

The origin is placed at the centre of the bounding box, as for every other georeferenced format: f32 storage cannot hold absolute coordinates in the hundreds of thousands and millimetres at the same time.